@@ -74,18 +74,17 @@ class bloatectomy():
             import pandas as pd
             assert (type(input_text) == list or type(input_text) == numpy.ndarray), "unsupported format"
             print('pulling notes from postgres database')
+            # select one of the hadm_id s in the list and get the concatenated notes for that hadm_id
             for i in input_text:
-                # select one of the hadm_id s in the list and get the concatenated notes for that hadm_id
                 print(style + "ing duplications in ID " + str(i))
-                print("Output file = " + path + filename + '.' + output)
                 # in this table, we have concatenated all notes from each hadm_id into a single document
                 query = """SELECT text FROM {0} WHERE hadm_id IN ({1})"""
                 query = query.format(self.postgres_table, i)
                 pt_text = pd.read_sql(query, self.engine)
-                #self.input_text = ''
+                self.input_text = ''
                 self.input_text = pt_text.text.to_list()[0]
                 #self.filename = ''
-                self.filename = str(i) + filename
+                self.filename = self.filename + '_' + str(i)
                 bloatectomy.main(self)
                 print("Output file = " + path + self.filename + '.' + output)
 
